Class: Google::Cloud::Support::V2::CommentService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/support/v2/comment_service/client.rb

Overview

Client for the CommentService service.

A service to manage comments on cases.

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#case_path, #comment_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new CommentService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::Support::V2::CommentService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::Support::V2::CommentService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the CommentService client.

Yield Parameters:



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 131

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/support/v2/comment_service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @comment_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::Support::V2::CommentService::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @comment_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the CommentService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all CommentService clients
::Google::Cloud::Support::V2::CommentService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 62

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "Support", "V2"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.list_comments.timeout = 60.0
    default_config.rpcs.list_comments.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.create_comment.timeout = 60.0

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the CommentService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:



101
102
103
104
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 101

def configure
  yield @config if block_given?
  @config
end

#create_comment(request, options = nil) ⇒ ::Google::Cloud::Support::V2::Comment #create_comment(parent: nil, comment: nil) ⇒ ::Google::Cloud::Support::V2::Comment

Add a new comment to a case.

The comment must have the following fields set: body.

EXAMPLES:

cURL:

case="projects/some-project/cases/43591344"
curl \
  --request POST \
  --header "Authorization: Bearer $(gcloud auth print-access-token)" \
  --header 'Content-Type: application/json' \
  --data '{
    "body": "This is a test comment."
  }' \
  "https://cloudsupport.googleapis.com/v2/$case/comments"

Python:

import googleapiclient.discovery

api_version = "v2"
supportApiService = googleapiclient.discovery.build(
    serviceName="cloudsupport",
    version=api_version,
    discoveryServiceUrl=f"https://cloudsupport.googleapis.com/$discovery/rest?version=\\{api_version}",
)
request = (
    supportApiService.cases()
    .comments()
    .create(
        parent="projects/some-project/cases/43595344",
        body=\\{"body": "This is a test comment."},
    )
)
print(request.execute())

Examples:

Basic example

require "google/cloud/support/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Support::V2::CommentService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Support::V2::CreateCommentRequest.new

# Call the create_comment method.
result = client.create_comment request

# The returned object is of type Google::Cloud::Support::V2::Comment.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 405

def create_comment request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::CreateCommentRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_comment..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Support::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_comment.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_comment.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @comment_service_stub.call_rpc :create_comment, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_comments(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::Comment> #list_comments(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::Comment>

List all the comments associated with a case.

EXAMPLES:

cURL:

case="projects/some-project/cases/43595344"
curl \
  --header "Authorization: Bearer $(gcloud auth print-access-token)" \
  "https://cloudsupport.googleapis.com/v2/$case/comments"

Python:

import googleapiclient.discovery

api_version = "v2"
supportApiService = googleapiclient.discovery.build(
    serviceName="cloudsupport",
    version=api_version,
    discoveryServiceUrl=f"https://cloudsupport.googleapis.com/$discovery/rest?version=\\{api_version}",
)
request = (
    supportApiService.cases()
    .comments()
    .list(parent="projects/some-project/cases/43595344")
)
print(request.execute())

Examples:

Basic example

require "google/cloud/support/v2"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::Support::V2::CommentService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::Support::V2::ListCommentsRequest.new

# Call the list_comments method.
result = client.list_comments request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::Support::V2::Comment.
  p item
end

Overloads:

  • #list_comments(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::Comment>

    Pass arguments to list_comments via a request object, either of type ListCommentsRequest or an equivalent Hash.

  • #list_comments(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::Comment>

    Pass arguments to list_comments via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 276

def list_comments request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::ListCommentsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_comments..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::Support::V2::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_comments.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_comments.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @comment_service_stub.call_rpc :list_comments, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @comment_service_stub, :list_comments, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.



187
188
189
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 187

def logger
  @comment_service_stub.logger
end

#universe_domainString

The effective universe domain



111
112
113
# File 'lib/google/cloud/support/v2/comment_service/client.rb', line 111

def universe_domain
  @comment_service_stub.universe_domain
end