Class: Google::Cloud::Support::V2::ListSupportEventSubscriptionsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Support::V2::ListSupportEventSubscriptionsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/support/v2/support_event_subscription_service.rb
Overview
Response message for ListSupportEventSubscriptions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token, which can be sent as
page_tokento retrieve the next page. -
#support_event_subscriptions ⇒ ::Array<::Google::Cloud::Support::V2::SupportEventSubscription>
The support event subscriptions.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token, which can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
93 94 95 96 |
# File 'proto_docs/google/cloud/support/v2/support_event_subscription_service.rb', line 93 class ListSupportEventSubscriptionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#support_event_subscriptions ⇒ ::Array<::Google::Cloud::Support::V2::SupportEventSubscription>
Returns The support event subscriptions.
93 94 95 96 |
# File 'proto_docs/google/cloud/support/v2/support_event_subscription_service.rb', line 93 class ListSupportEventSubscriptionsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |