Class: Google::Cloud::Support::V2::SearchCaseClassificationsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Support::V2::SearchCaseClassificationsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/support/v2/case_service.rb
Overview
The request message for the SearchCaseClassifications endpoint.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
The maximum number of classifications fetched with each request.
-
#page_token ⇒ ::String
A token identifying the page of results to return.
-
#query ⇒ ::String
An expression used to filter case classifications.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns The maximum number of classifications fetched with each request.
217 218 219 220 |
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 217 class SearchCaseClassificationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A token identifying the page of results to return. If unspecified, the first page is retrieved.
217 218 219 220 |
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 217 class SearchCaseClassificationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::String
Returns An expression used to filter case classifications.
If it's an empty string, then no filtering happens. Otherwise, case classifications will be returned that match the filter.
217 218 219 220 |
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 217 class SearchCaseClassificationsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |