Class: Google::Cloud::Support::V2::SearchCasesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/support/v2/case_service.rb

Overview

The request message for the SearchCases endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns The maximum number of cases fetched with each request. The default page size is 10.

Returns:

  • (::Integer)

    The maximum number of cases fetched with each request. The default page size is 10.



159
160
161
162
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 159

class SearchCasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns A token identifying the page of results to return. If unspecified, the first page is retrieved.

Returns:

  • (::String)

    A token identifying the page of results to return. If unspecified, the first page is retrieved.



159
160
161
162
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 159

class SearchCasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns The name of the parent resource to search for cases under.

Returns:

  • (::String)

    The name of the parent resource to search for cases under.



159
160
161
162
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 159

class SearchCasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#query::String

Returns An expression used to filter cases.

Expressions use the following fields separated by AND and specified with =:

  • state: Can be OPEN or CLOSED.
  • priority: Can be P0, P1, P2, P3, or P4. You can specify multiple values for priority using the OR operator. For example, priority=P1 OR priority=P2.
  • creator.email: The email address of the case creator.

To search across displayName, description, and comments, use a global restriction with no keyword or operator. For example, "my search".

To search only cases updated after a certain date, use update_time restricted with that particular date, time, and timezone in ISO datetime format. For example, update_time>"2020-01-01T00:00:00-05:00". update_time only supports the greater than operator (>).

If you are using the v2 version of the API, you must specify the case parent in the parent field. If you provide an empty query, all cases under the parent resource will be returned.

If you are using the v2beta version of the API, you must specify the case parent in the query field using one of the two fields below, which are only available for v2beta. The parent field will be ignored.

  • organization: An organization name in the form organizations/<organization_id>.
  • project: A project name in the form projects/<project_id>.

Examples:

For v2:

  • state=CLOSED
  • state=OPEN AND creator.email="tester@example.com"
  • state=OPEN AND (priority=P0 OR priority=P1)
  • update_time>"2020-01-01T00:00:00-05:00"

For v2beta:

  • organization="organizations/123456789"
  • project="projects/my-project-id"
  • project="projects/123456789"
  • organization="organizations/123456789" AND state=CLOSED
  • project="projects/my-project-id" AND creator.email="tester@example.com"
  • project="projects/my-project-id" AND (priority=P0 OR priority=P1).

Returns:

  • (::String)

    An expression used to filter cases.

    Expressions use the following fields separated by AND and specified with =:

    • state: Can be OPEN or CLOSED.
    • priority: Can be P0, P1, P2, P3, or P4. You can specify multiple values for priority using the OR operator. For example, priority=P1 OR priority=P2.
    • creator.email: The email address of the case creator.

    To search across displayName, description, and comments, use a global restriction with no keyword or operator. For example, "my search".

    To search only cases updated after a certain date, use update_time restricted with that particular date, time, and timezone in ISO datetime format. For example, update_time>"2020-01-01T00:00:00-05:00". update_time only supports the greater than operator (>).

    If you are using the v2 version of the API, you must specify the case parent in the parent field. If you provide an empty query, all cases under the parent resource will be returned.

    If you are using the v2beta version of the API, you must specify the case parent in the query field using one of the two fields below, which are only available for v2beta. The parent field will be ignored.

    • organization: An organization name in the form organizations/<organization_id>.
    • project: A project name in the form projects/<project_id>.

    Examples:

    For v2:

    • state=CLOSED
    • state=OPEN AND creator.email="tester@example.com"
    • state=OPEN AND (priority=P0 OR priority=P1)
    • update_time>"2020-01-01T00:00:00-05:00"

    For v2beta:

    • organization="organizations/123456789"
    • project="projects/my-project-id"
    • project="projects/123456789"
    • organization="organizations/123456789" AND state=CLOSED
    • project="projects/my-project-id" AND creator.email="tester@example.com"
    • project="projects/my-project-id" AND (priority=P0 OR priority=P1)


159
160
161
162
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 159

class SearchCasesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end