Class: Google::Cloud::Support::V2::SearchCasesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/support/v2/case_service.rb

Overview

The response message for the SearchCases endpoint.

Instance Attribute Summary collapse

Instance Attribute Details

#cases::Array<::Google::Cloud::Support::V2::Case>

Returns The list of cases associated with the parent after any filters have been applied.

Returns:



158
159
160
161
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 158

class SearchCasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to retrieve the next page of results. Set this in the page_token field of subsequent cases.search requests. If unspecified, there are no more results to retrieve.

Returns:

  • (::String)

    A token to retrieve the next page of results. Set this in the page_token field of subsequent cases.search requests. If unspecified, there are no more results to retrieve.



158
159
160
161
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 158

class SearchCasesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end