Class: Google::Cloud::Support::V2::SupportEventSubscriptionService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Support::V2::SupportEventSubscriptionService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/support/v2/support_event_subscription_service/client.rb
Overview
Client for the SupportEventSubscriptionService service.
Service for managing customer support event subscriptions.
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client instance.
-
#create_support_event_subscription(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Creates a support event subscription for an organization.
-
#delete_support_event_subscription(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Soft deletes a support event subscription.
-
#get_support_event_subscription(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Gets a support event subscription.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new SupportEventSubscriptionService client object.
-
#list_support_event_subscriptions(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::SupportEventSubscription>
Lists support event subscriptions.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#undelete_support_event_subscription(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Undeletes a support event subscription.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_support_event_subscription(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Updates a support event subscription.
Methods included from Paths
#organization_path, #support_event_subscription_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new SupportEventSubscriptionService client object.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 124 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/support/v2/support_event_subscription_service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @support_event_subscription_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::Support::V2::SupportEventSubscriptionService::Stub, credentials: credentials, endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, channel_args: @config.channel_args, interceptors: @config.interceptors, channel_pool_config: @config.channel_pool, logger: @config.logger ) @support_event_subscription_service_stub.stub_logger&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client class.
See Configuration for a description of the configuration fields.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 62 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Support", "V2"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the SupportEventSubscriptionService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
94 95 96 97 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 94 def configure yield @config if block_given? @config end |
#create_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription #create_support_event_subscription(parent: nil, support_event_subscription: nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Creates a support event subscription for an organization.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 233 def create_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::CreateSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.create_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.call_rpc :create_support_event_subscription, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription #delete_support_event_subscription(name: nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Soft deletes a support event subscription.
611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 611 def delete_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::DeleteSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.delete_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.call_rpc :delete_support_event_subscription, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription #get_support_event_subscription(name: nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Gets a support event subscription.
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 320 def get_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::GetSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.get_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.call_rpc :get_support_event_subscription, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_support_event_subscriptions(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::SupportEventSubscription> #list_support_event_subscriptions(parent: nil, filter: nil, show_deleted: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::Support::V2::SupportEventSubscription>
Lists support event subscriptions.
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 433 def list_support_event_subscriptions request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::ListSupportEventSubscriptionsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_support_event_subscriptions..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.parent header_params["parent"] = request.parent end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_support_event_subscriptions.timeout, metadata: , retry_policy: @config.rpcs.list_support_event_subscriptions.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.call_rpc :list_support_event_subscriptions, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @support_event_subscription_service_stub, :list_support_event_subscriptions, request, response, operation, yield response, operation if block_given? throw :response, response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
180 181 182 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 180 def logger @support_event_subscription_service_stub.logger end |
#undelete_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription #undelete_support_event_subscription(name: nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Undeletes a support event subscription.
698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 698 def undelete_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::UndeleteSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.undelete_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.name header_params["name"] = request.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.undelete_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.undelete_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.call_rpc :undelete_support_event_subscription, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
104 105 106 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 104 def universe_domain @support_event_subscription_service_stub.universe_domain end |
#update_support_event_subscription(request, options = nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription #update_support_event_subscription(support_event_subscription: nil, update_mask: nil) ⇒ ::Google::Cloud::Support::V2::SupportEventSubscription
Updates a support event subscription.
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 |
# File 'lib/google/cloud/support/v2/support_event_subscription_service/client.rb', line 524 def update_support_event_subscription request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Support::V2::UpdateSupportEventSubscriptionRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_support_event_subscription..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::Support::V2::VERSION [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = {} if request.support_event_subscription&.name header_params["support_event_subscription.name"] = request.support_event_subscription.name end request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_support_event_subscription.timeout, metadata: , retry_policy: @config.rpcs.update_support_event_subscription.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @support_event_subscription_service_stub.call_rpc :update_support_event_subscription, request, options: do |response, operation| yield response, operation if block_given? end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |