Class: Google::Cloud::Support::V2::SearchCasesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::Support::V2::SearchCasesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/support/v2/case_service.rb
Overview
The response message for the SearchCases endpoint.
Instance Attribute Summary collapse
-
#cases ⇒ ::Array<::Google::Cloud::Support::V2::Case>
The list of cases associated with the parent after any filters have been applied.
-
#next_page_token ⇒ ::String
A token to retrieve the next page of results.
Instance Attribute Details
#cases ⇒ ::Array<::Google::Cloud::Support::V2::Case>
Returns The list of cases associated with the parent after any filters have been applied.
158 159 160 161 |
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 158 class SearchCasesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token to retrieve the next page of results. Set this in the
page_token field of subsequent cases.search requests. If unspecified,
there are no more results to retrieve.
158 159 160 161 |
# File 'proto_docs/google/cloud/support/v2/case_service.rb', line 158 class SearchCasesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |